@@ -9,7 +9,7 @@ use MooX::LazierAttributes qw/lzy bld coe/;
 use MooX::ValidateSubs;
 use Coerce::Types::Standard qw/HTML Str Object StrToArray/;
 
-our $VERSION = '0.74005';
+our $VERSION = '0.74006';
 
 our %encode;
 BEGIN {
@@ -89,7 +89,7 @@ HTML::SocialMeta - Module to generate Social Media Meta Tags,
 
 =head1 VERSION
 
-Version 0.74005
+Version 0.74006
 
 =head1 SYNOPSIS
 
@@ -129,7 +129,7 @@ Version 0.74005
     $c->stash->{meta_tags} = $meta_tags;
     
     # template
-    [% meta_tags | html %]
+    [% meta_tags %]
 
 =head1 DESCRIPTION
 
